@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """This module contains Trakt.tv sync endpoint support functions"""
-from datetime import datetime
+from datetime import datetime, timezone
 
 from trakt.core import get, post, delete
 from trakt.utils import slugify, extract_ids, timestamp
@@ -10,7 +10,8 @@ __author__ = 'Jon Nappi'
 __all__ = ['Scrobbler', 'comment', 'rate', 'add_to_history', 'get_collection',
            'get_watchlist', 'add_to_watchlist', 'remove_from_history',
            'remove_from_watchlist', 'add_to_collection',
-           'remove_from_collection', 'search', 'search_by_id']
+           'remove_from_collection', 'search', 'search_by_id', 'checkin_media',
+           'delete_checkin']
 
 
 @post
@@ -46,7 +47,7 @@ def rate(media, rating, rated_at=None):
         this rating was created
     """
     if rated_at is None:
-        rated_at = datetime.now()
+        rated_at = datetime.now(tz=timezone.utc)
 
     data = dict(rating=rating, rated_at=timestamp(rated_at))
     data.update(media.ids)
@@ -64,7 +65,7 @@ def add_to_history(media, watched_at=None):
         which this media item was viewed
     """
     if watched_at is None:
-        watched_at = datetime.now()
+        watched_at = datetime.now(tz=timezone.utc)
 
     data = dict(watched_at=timestamp(watched_at))
     data.update(media.ids)
